Struct chemistru_elements::data::electron::ElectronData
source · pub struct ElectronData {
pub shells: [u8; 8],
pub ionisation_energies: [f64; 30],
pub electron_configuration: ElectronConfiguration,
pub electron_affinity: Option<f64>,
pub electronegativity: Option<f64>,
}Fields
shells: [u8; 8]ionisation_energies: [f64; 30]electron_configuration: ElectronConfigurationelectron_affinity: Option<f64>electronegativity: Option<f64>Trait Implementations
sourceimpl Clone for ElectronData
impl Clone for ElectronData
sourcefn clone(&self) -> ElectronData
fn clone(&self) -> ElectronData
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for ElectronData
impl Debug for ElectronData
sourceimpl PartialEq for ElectronData
impl PartialEq for ElectronData
sourcefn eq(&self, other: &ElectronData) -> bool
fn eq(&self, other: &ElectronData) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd for ElectronData
impl PartialOrd for ElectronData
sourcefn partial_cmp(&self, other: &ElectronData) -> Option<Ordering>
fn partial_cmp(&self, other: &ElectronData) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moresourceimpl ToTokens for ElectronData
impl ToTokens for ElectronData
sourcefn to_tokens(&self, tokens: &mut TokenStream)
fn to_tokens(&self, tokens: &mut TokenStream)
sourcefn to_token_stream(&self) -> TokenStream
fn to_token_stream(&self) -> TokenStream
sourcefn into_token_stream(self) -> TokenStreamwhere
Self: Sized,
fn into_token_stream(self) -> TokenStreamwhere Self: Sized,
impl Copy for ElectronData
impl StructuralPartialEq for ElectronData