Struct chemistru_elements::element::ElementName
source · pub struct ElementName(pub [char; 13], pub usize);Tuple Fields
0: [char; 13]1: usizeTrait Implementations
sourceimpl Clone for ElementName
impl Clone for ElementName
sourcefn clone(&self) -> ElementName
fn clone(&self) -> ElementName
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for ElementName
impl Debug for ElementName
sourceimpl Ord for ElementName
impl Ord for ElementName
sourcefn cmp(&self, other: &ElementName) -> Ordering
fn cmp(&self, other: &ElementName) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
sourceimpl PartialEq for ElementName
impl PartialEq for ElementName
sourcefn eq(&self, other: &ElementName) -> bool
fn eq(&self, other: &ElementName) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd for ElementName
impl PartialOrd for ElementName
sourcefn partial_cmp(&self, other: &ElementName) -> Option<Ordering>
fn partial_cmp(&self, other: &ElementName) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moresourceimpl ToString for ElementName
impl ToString for ElementName
impl Copy for ElementName
impl Eq for ElementName
impl StructuralEq for ElementName
impl StructuralPartialEq for ElementName