pub struct InnerElement {
    pub name: &'static str,
    pub symbol: &'static str,
    pub description: &'static str,
    pub atomic_data: AtomicData,
    pub state_data: StateData,
    pub electron_data: ElectronData,
}
Detailed information about an element

Should be held behind avstatic reference where possible due to large size

Large size is due to being made able to be static or constant

Fields

name: &'static strsymbol: &'static strdescription: &'static stratomic_data: AtomicDatastate_data: StateDataelectron_data: ElectronData