Struct chemistru_elements::raw::AtomicData
source · pub struct AtomicData {
pub atomic_number: u8,
pub nucleon_number: u16,
pub atomic_mass: f64,
}Fields
atomic_number: u8nucleon_number: u16atomic_mass: f64Trait Implementations
sourceimpl Clone for AtomicData
impl Clone for AtomicData
sourcefn clone(&self) -> AtomicData
fn clone(&self) -> AtomicData
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for AtomicData
impl Debug for AtomicData
sourceimpl PartialEq for AtomicData
impl PartialEq for AtomicData
sourcefn eq(&self, other: &AtomicData) -> bool
fn eq(&self, other: &AtomicData) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd for AtomicData
impl PartialOrd for AtomicData
sourcefn partial_cmp(&self, other: &AtomicData) -> Option<Ordering>
fn partial_cmp(&self, other: &AtomicData) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moreimpl Copy for AtomicData
impl StructuralPartialEq for AtomicData