Struct chemistru_elements::raw::ElectronConfiguration
source · pub struct ElectronConfiguration {}Trait Implementations
sourceimpl Clone for ElectronConfiguration
impl Clone for ElectronConfiguration
sourcefn clone(&self) -> ElectronConfiguration
fn clone(&self) -> ElectronConfiguration
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for ElectronConfiguration
impl Debug for ElectronConfiguration
sourceimpl PartialEq for ElectronConfiguration
impl PartialEq for ElectronConfiguration
sourcefn eq(&self, other: &ElectronConfiguration) -> bool
fn eq(&self, other: &ElectronConfiguration) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd for ElectronConfiguration
impl PartialOrd for ElectronConfiguration
sourcefn partial_cmp(&self, other: &ElectronConfiguration) -> Option<Ordering>
fn partial_cmp(&self, other: &ElectronConfiguration) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moreimpl Copy for ElectronConfiguration
impl StructuralPartialEq for ElectronConfiguration