Struct chemistru_elements::raw::ElectronData
source · pub struct ElectronData {
pub electron_configuration: ElectronConfiguration,
pub ionisation_energies: Vec<f64>,
}Fields
electron_configuration: ElectronConfigurationionisation_energies: Vec<f64>Trait Implementations
sourceimpl Clone for ElectronData
impl Clone for ElectronData
sourcefn clone(&self) -> ElectronData
fn clone(&self) -> ElectronData
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for ElectronData
impl Debug for ElectronData
sourceimpl PartialEq for ElectronData
impl PartialEq for ElectronData
sourcefn eq(&self, other: &ElectronData) -> bool
fn eq(&self, other: &ElectronData) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd for ElectronData
impl PartialOrd for ElectronData
sourcefn partial_cmp(&self, other: &ElectronData) -> Option<Ordering>
fn partial_cmp(&self, other: &ElectronData) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moreimpl StructuralPartialEq for ElectronData