Struct chemistru_elements::inner::InnerElement
source · pub struct InnerElement {
pub name: &'static str,
pub symbol: &'static str,
pub description: &'static str,
pub atomic_data: AtomicData,
pub state_data: StateData,
pub electron_data: ElectronData,
}Expand description
Detailed information about an element
Should be held behind avstatic reference where possible due to large size
Large size is due to being made able to be static or constant
Fields
name: &'static strsymbol: &'static strdescription: &'static stratomic_data: AtomicDatastate_data: StateDataelectron_data: ElectronDataTrait Implementations
sourceimpl Clone for InnerElement
impl Clone for InnerElement
sourcefn clone(&self) -> InnerElement
fn clone(&self) -> InnerElement
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for InnerElement
impl Debug for InnerElement
sourceimpl PartialEq for InnerElement
impl PartialEq for InnerElement
sourcefn eq(&self, other: &InnerElement) -> bool
fn eq(&self, other: &InnerElement) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd for InnerElement
impl PartialOrd for InnerElement
sourcefn partial_cmp(&self, other: &InnerElement) -> Option<Ordering>
fn partial_cmp(&self, other: &InnerElement) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moresourceimpl ToTokens for InnerElement
impl ToTokens for InnerElement
sourcefn to_tokens(&self, stream: &mut TokenStream)
fn to_tokens(&self, stream: &mut TokenStream)
sourcefn to_token_stream(&self) -> TokenStream
fn to_token_stream(&self) -> TokenStream
sourcefn into_token_stream(self) -> TokenStreamwhere
Self: Sized,
fn into_token_stream(self) -> TokenStreamwhere Self: Sized,
impl StructuralPartialEq for InnerElement